import { TablePropsV2, TableV2 } from 'aws-cdk-lib/aws-dynamodb';
import { Construct } from 'constructs';
/**
 * CloudKitect DynamodDB Table Component Properties
 */
export interface CkTableV2Props extends TablePropsV2 {
}
/**
 * CloudKitect DynamoDB Table V2 component
 *
 * ### Default Configuration
 * * Encryption: Keys managed by AWS in customer account
 *
 * ### Default Alarms
 * Available only in Enhanced components
 *
 * ### Logging and Monitoring
 * Available only in Enhanced components
 *
 * ### Backups
 * Available only in Enhanced components
 *
 * ### Examples
 * Default Usage
 * ```ts
 * new CkTableV2(this, "LogicalId", {});
 * ```
 *
 * Custom Configuration
 * ```ts
 * new CkTableV2(this, "LogicalId", {
 *    encryption: TableEncryption.AWS_MANAGED
 * });
 * ```
 *
 * ### Compliance
 * It addresses the following compliance requirements
 * 1. DynamoDB point in time recovery
 *    >  - Risk Level: High
 *    >  - Compliance: NIST4
 *    >  - Well Architected Pillar: Reliability
 * 2. Encryption key in customer account
 *    >  - Risk Level: Medium
 *    >  - Compliance: NIST4
 *    >  - Well Architected Pillar: Security
 *
 *    ![Compliance Check Report](http://cloudkitect.com/wp-content/uploads/2024/01/dynamodb-compliance.png)
 */
export declare class CkTableV2 extends TableV2 {
    private static getEncryptionStrategy;
    private static getTableClassStrategy;
    constructor(scope: Construct, id: string, props: CkTableV2Props);
}
