import * as ec2 from 'aws-cdk-lib/aws-ec2';
import { Construct } from 'constructs';
/**
 * CloudKitect VPC Component properties
 */
export interface CkVpcProps extends ec2.VpcProps {
}
/**
 * CloudKitect Virtual Private Cloud - VPC component
 *
 * ### Default Configuration
 * Subnets: Public, Private, Isolated,
 *
 * ### Default Alarms
 * Available only in Enhanced components
 *
 * ### Logging and Monitoring
 * Available only in Enhanced components
 *
 * ### Examples
 * Default Usage
 * ```ts
 * new CkVpc(this, "LogicalId", {});
 * ```
 *
 * Custom Configuration
 * ```ts
 * new CkVpc(this, "LogicalId", {
 *    enableDnsHostnames: false
 * });
 * ```
 *
 * ### Compliance
 * It addresses the following compliance requirements
 * 1. Highly available NAT Gateway in use
 *    >  - Risk Level: Medium
 *    >  - Compliance: APRA, MAS, NIST4
 *    >  - Well Architected Pillar: Performance Efficiency
 * 2. Restrict default security groups
 *    >  - Risk Level: Medium
 *    >  - Compliance: NIST4
 *    >  - Well Architected Pillar: Security
 * 3. Create three subnets Public, Private and Isolated
 *    >  - Risk Level: Medium
 *    >  - Compliance: NIST4
 *    >  - Well Architected Pillar: Security
 */
export declare class CkVpc extends ec2.Vpc {
    constructor(scope: Construct, id: string, props: CkVpcProps);
}
