import * as ecs from 'aws-cdk-lib/aws-ecs';
import { Construct } from 'constructs';
/**
 * CloudKitect Cluster component properties
 */
export interface CkClusterProps extends ecs.ClusterProps {
}
/**
 * CloudKitect ECS cluster component is a regional grouping of one or more container instances on
 * which you can run tasks and services and enables container insights,
 *
 * ### Default Configuration
 * New VPC is created by default.
 *
 * ### Default Alarms
 * Available only in Enhanced components
 *
 * ### Logging and Monitoring
 * Available only in Enhanced components
 *
 * ### Examples
 * Default Usage
 * ```ts
 * new CkCluster(this, "LogicalId", {});
 * ```
 *
 * Custom Configuration
 * ```ts
 * new CkCluster(this, "LogicalId", {
 *    containerInsights: false
 * });
 * ```
 *
 * ### Compliance
 * It addresses the following compliance requirements
 *
 */
export declare class CkCluster extends ecs.Cluster {
    constructor(scope: Construct, id: string, props: CkClusterProps);
}
