import { Construct } from 'constructs';
import { CkCluster, CkClusterProps } from './ck-cluster';
/**
 * CloudKitect Fargate Cluster component properties
 */
export interface CkFargateClusterProps extends CkClusterProps {
}
/**
 * CloudKitect ECS cluster component backed by Fargate capacity provider is a regional grouping of
 * one or more container instances on which you can run tasks and services and enables container insights,
 *
 * ### Default Alarms
 *
 * ### Examples
 * Default Usage
 * ```ts
 * new CcFargateCluster(this, "LogicalId", {});
 * ```
 *
 * Custom Configuration
 * ```ts
 * new CcFargateCluster(this, "LogicalId", {
 *    containerInsights: false
 * });
 * ```
 *
 * ### Compliance
 * It addresses the following compliance requirements
 * 1. Cluster insights enabled
 *    >  - Risk Level: Medium
 *    >  - Compliance: NA
 *    >  - Well Architected Pillar: Operational Excellence
 */
export declare class CkFargateCluster extends CkCluster {
    constructor(scope: Construct, id: string, props: CkFargateClusterProps);
}
