import { SecurityGroup } from 'aws-cdk-lib/aws-ec2';
import * as elbv2 from 'aws-cdk-lib/aws-elasticloadbalancingv2';
import { Construct } from 'constructs';
/**
 * CloudKitect  Public Application Load Balancer component properties.
 */
export interface CkPublicApplicationLoadBalancerProps extends elbv2.ApplicationLoadBalancerProps {
}
/**
 * CloudKitect Public Application Load Balancer component.
 * This load balancer is created in public subnet
 *
 * ### Default Configuration
 * Drop Invalid header fields: true
 * Removal Policy: Retain in Production
 *
 * ### Default Alarms
 * Available only in Enhanced components
 *
 * ### Logging and Monitoring
 * Available only in Enhanced components
 *
 * ### Examples
 * Default Usage
 * ```ts
 * new CkPublicApplicationLoadbalancer(this, "LogicalId", {});
 * ```
 *
 * Custom Configuration
 * ```ts
 * new CkPublicApplicationLoadbalancer(this, "LogicalId", {
 *    deletionProtection: false
 * });
 * ```
 *
 * ### Compliance
 * It addresses the following compliance requirements
 * 1. Ensure ALB is always using https, by redirecting http to https
 *    >  - Risk Level: High
 *    >  - Compliance: PCI, APRA, NIST4
 *    >  - Well Architected Pillar: Security
 * 2. Security group to only allow https traffic
 *    >  - Risk Level: High
 *    >  - Compliance: PCI, APRA, MAS, NIST4
 *    >  - Well Architected Pillar: Security
 *
 */
export declare class CkPublicApplicationLoadbalancer extends elbv2.ApplicationLoadBalancer {
    /**
       * Security group created inside load balancer that only allows traffic from https
       */
    readonly lbSecurityGroup: SecurityGroup;
    constructor(scope: Construct, id: string, props: CkPublicApplicationLoadBalancerProps);
}
