import * as s3 from 'aws-cdk-lib/aws-s3';
import { Construct } from 'constructs';
/**
 * CloudKitect Bucket component properties
 */
export interface CkBucketProps extends s3.BucketProps {
}
/**
 * CloudKitect S3 Bucket component
 *
 * ### Default Configuration
 * Encryption: S3 Managed
 * Versioned: True
 * Removal Policy: Retain in Production
 *
 * ### Default Alarms
 * Available only in Enhanced components
 *
 * ### Logging and Monitoring
 * Available only in Enhanced components
 *
 * Note that the default alarm uses the CcAlarm construct, which sets up an alarm
 * action to notify the SNS Topic *AlarmEventsTopic* by default.
 *
 * ### Examples
 * Default Usage
 * ```ts
 * new CkBucket(this, "LogicalId", {
 * });
 * ```
 *
 * Custom Configuration
 * ```ts
 * new CkBucket(this, "LogicalId", {
 *    enforceSSL: false
 * });
 * ```
 *
 * ### Compliance
 * It addresses the following compliance requirements
 * 1. Blocks public access
 *    >  - Risk Level: Medium
 *    >  - Compliance: PCI, HIPAA, GDPR, APRA, MAS, NIST4
 *    >  - Well Architected Pillar: Security
 * 2. Bucket versioning enabled in Production Environment
 *    >  - Risk Level: Low
 *    >  - Compliance: PCI, APRA, MAS, NIST4
 *    >  - Well Architected Pillar: Reliability
 * 3. Block S3 Bucket Public 'READ' Access
 *    >  - Risk Level: Very High
 *    >  - Compliance: PCI, GDPR, ARPA, MAS, NIST4
 *    >  - Well Architected Pillar: Security
 * 4. Only allow secure transport protocols
 *    >  - Risk Level: High
 *    >  - Compliance: PCI, APRA, MAS, NIST4
 *    >  - Well Architected Pillar: Security
 * 5. Server side encryption
 *    >  - Risk Level: High
 *    >  - Compliance: PCI, HIPAA, GDPR, APRA, MAS, NIST4
 *    >  - Well Architected Pillar: Security
 *
 */
export declare class CkBucket extends s3.Bucket {
    constructor(scope: Construct, id: string, props: CkBucketProps);
}
